@@ -3,7 +3,7 @@
 # License: MIT
 from __future__ import unicode_literals
 
-__author__ = "Raphaël Barrois <raphael.barrois@polytechnique.org>"
-__version__ = '1.1.0'
+__author__ = "Raphaël Barrois <raphael.barrois+restrictedpkg@polytechnique.org>"
+__version__ = '1.1.1'
 
 from .commands import setup
